@@ -75,5 +75,9 @@ def _f_expl_2_fehlberg_adptv(x0, Y0, dx, *args, dYdx=None, econ=0.0324, eps=0.1,
         return False
 
 
-expl_2_fehlberg_adptv = Scheme(
-    _f_expl_2_fehlberg_adptv, description="Explicit adaptive 2nd-order Fehlberg's method")
+class expl_2_fehlberg_adptv(Scheme):
+    """Class for explicit adaptive 2nd-order Fehlberg's method"""
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(_f_expl_2_fehlberg_adptv,
+                         description="Explicit adaptive 2nd-order Fehlberg's method", *args, **kwargs)
