@@ -40,5 +40,9 @@ def _f_expl_2_ralston(x0, Y0, dx, *args, dYdx=None, **kwargs):
     return dx*(b0*k0 + b1*k1)
 
 
-expl_2_ralston = Scheme(
-    _f_expl_2_ralston, description="Explicit 2nd-order Ralston's method")
+class expl_2_ralston(Scheme):
+    """Class for explicit 2nd-order Ralston's method"""
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(_f_expl_2_ralston,
+                         description="Explicit 2nd-order Ralston's method", *args, **kwargs)
